==> lighterend-1.0.0-0-1.21.9-sources.jar: io/github/openbagtwo/lighterend/blocks/entities/PedestalDisplay.java <==
package io.github.openbagtwo.lighterend.blocks.entities;

import io.github.openbagtwo.lighterend.registries.LighterEndBlockEntities;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1262;
import net.minecraft.class_1264;
import net.minecraft.class_1278;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2371;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;
import org.jetbrains.annotations.Nullable;

public class PedestalDisplay extends class_2586 implements class_1278 {

  private final class_2371<class_1799> inventory = class_2371.method_10213(1, class_1799.field_8037);
  private float rotation = 0;

  public PedestalDisplay(class_2338 pos, class_2680 state) {
    super(LighterEndBlockEntities.PEDESTAL, pos, state);
  }

  public class_2371<class_1799> getItems() {
    return inventory;
  }

  public float getRenderingRotation() {
    rotation += 0.5f;
    if (rotation >= 360) {
      rotation = 0;
    }
    return rotation;
  }

  @Override
  protected void method_11007(class_11372 view) {
    super.method_11007(view);
    class_1262.method_5426(view, inventory);
  }

  @Override
  protected void method_11014(class_11368 view) {
    super.method_11014(view);
    class_1262.method_5429(view, inventory);
  }

  @Override
  public void method_66473(class_2338 pos, class_2680 oldState) {
    class_1264.method_5451(field_11863, pos, this);
    super.method_66473(pos, oldState);
  }

  @Override
  public class_2596<class_2602> method_38235() {
    return class_2622.method_38585(this);
  }

  @Override
  public class_2487 method_16887(class_7225.class_7874 registryLookup) {
    return method_38244(registryLookup);
  }

  @Override
  public int[] method_5494(class_2350 side) {
    return new int[0];
  }

  @Override
  public boolean method_5492(int slot, class_1799 stack, @Nullable class_2350 dir) {
    return inventory.getFirst().method_7960();
  }

  @Override
  public boolean method_5493(int slot, class_1799 stack, class_2350 dir) {
    return !inventory.getFirst().method_7960();
  }

  @Override
  public int method_5439() {
    return inventory.size();
  }

  @Override
  public boolean method_5442() {
    return inventory.getFirst().method_7960();
  }

  @Override
  public class_1799 method_5438(int slot) {
    return inventory.getFirst();
  }

  @Override
  public class_1799 method_5434(int slot, int amount) {
    return this.method_5441(slot);
  }

  @Override
  public class_1799 method_5441(int slot) {
    if (slot == 0) {
      class_1799 stack = inventory.getFirst();
      inventory.set(0, class_1799.field_8037);
      return stack;
    }
    return null;
  }

  @Override
  public void method_5447(int slot, class_1799 stack) {
    if (slot == 0) {
      inventory.set(0, stack);
    }

  }

  @Override
  public boolean method_5443(class_1657 player) {
    return true;
  }

  @Override
  public void method_5448() {
    this.method_5441(0);
  }
}

==> lighterend-1.0.1-0-1.21.9-sources.jar: io/github/openbagtwo/lighterend/blocks/entities/PedestalDisplay.java <==
package io.github.openbagtwo.lighterend.blocks.entities;

import io.github.openbagtwo.lighterend.registries.LighterEndBlockEntities;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_11566;
import net.minecraft.class_11596;
import net.minecraft.class_1262;
import net.minecraft.class_1264;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2371;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;

public class PedestalDisplay extends class_2586 implements class_11566, class_11596 {

  private final class_2371<class_1799> inventory = class_2371.method_10213(1, class_1799.field_8037);
  private float rotation = 0;

  public PedestalDisplay(class_2338 pos, class_2680 state) {
    super(LighterEndBlockEntities.PEDESTAL, pos, state);
  }

  public class_2371<class_1799> getItems() {
    return inventory;
  }

  public float getRenderingRotation() {
    rotation += 0.5f;
    if (rotation >= 360) {
      rotation = 0;
    }
    return rotation;
  }

  @Override
  protected void method_11014(class_11368 view) {
    super.method_11014(view);
    this.inventory.clear();
    class_1262.method_5429(view, this.inventory);
  }

  @Override
  protected void method_11007(class_11372 view) {
    super.method_11007(view);
    class_1262.method_5427(view, this.inventory, true);
  }

  @Override
  public void method_66473(class_2338 pos, class_2680 oldState) {
    class_1264.method_5451(field_11863, pos, this);
    super.method_66473(pos, oldState);
  }

  @Override
  public class_2596<class_2602> method_38235() {
    return class_2622.method_38585(this);
  }

  @Override
  public class_2487 method_16887(class_7225.class_7874 registryLookup) {
    return method_38244(registryLookup);
  }

  @Override
  public class_2371<class_1799> method_72652() {
    return this.inventory;
  }

  @Override
  public int method_5439() {
    return inventory.size();
  }

  @Override
  public boolean method_5442() {
    return inventory.getFirst().method_7960();
  }

  @Override
  public class_1799 method_5438(int slot) {
    return inventory.getFirst();
  }

  @Override
  public class_1799 method_5434(int slot, int amount) {
    return this.method_5441(slot);
  }

  @Override
  public class_1799 method_5441(int slot) {
    if (slot == 0) {
      class_1799 stack = inventory.getFirst();
      inventory.set(0, class_1799.field_8037);
      return stack;
    }
    return null;
  }

  @Override
  public void method_5447(int slot, class_1799 stack) {
    if (slot == 0) {
      inventory.set(0, stack);
    }
  }

  @Override
  public boolean method_5443(class_1657 player) {
    return true;
  }

  @Override
  public void method_5448() {
    this.method_5441(0);
  }

  @Override
  public class_1937 method_73183() {
    return this.field_11863;
  }

  @Override
  public class_243 method_73189() {
    return this.method_11016().method_46558();
  }

  @Override
  public float method_73188() {
    return 0;
  }
}
